%define port          GTK
%define tarname       wxPython-src

%define api           3.0
%define libname       %mklibname %{name} %{api}

%define wxgtku_ver    3.0.2

%define gtkver        2
%define py_setup_args WX_CONFIG=%{_bindir}/wx-config-3.0 WXPORT=gtk%{gtkver}

Summary:        Cross platform GUI toolkit for Python using wx%{port}
Name:           wxPython
Epoch:          1
Version:        3.0.2.0
Release:        %mkrel 8
License:        LGPLv2+ and wxWidgets
Group:          Development/Python
URL:            http://wxPython.org/
Source0:        http://downloads.sourceforge.net/wxpython/%{tarname}-%{version}.tar.bz2
Patch0:         wxPython-3.0.0.0-literal.patch
# http://trac.wxwidgets.org/ticket/16765
Patch1:         wxPython-3.0.2.0-getxwindowcrash.patch
# http://trac.wxwidgets.org/ticket/16767
Patch2:         wxPython-3.0.2.0-plot.patch
BuildRequires:  wxgtk3.0-devel >= %{wxgtku_ver}
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(python2)
%if %{gtkver} == 3
BuildRequires:  pkgconfig(gtk+-3.0)
%endif
%if %{gtkver} == 2
BuildRequires:  pkgconfig(gtk+-2.0)
%endif

Provides:       wxwin
Provides:       wxPythonGTK = %{epoch}:%{version}-%{release}
Requires:       %{name}-wxversion = %{epoch}:%{version}-%{release}
Recommends:     %{name}-doc = %{epoch}:%{version}-%{release}

%description
wxPython is a GUI toolkit for Python that is a wrapper around the
wxWindows C++ GUI library.  wxPython provides a large variety of
window types and controls, all implemented with a native look and feel
(and native runtime speed) on the platforms it is supported on.

This package is implemented using the %{port} port of wxWindows.

%package        wxversion
Summary:        Select a specific version of %{name}
Group:          Development/Python

%description    wxversion
wxPython is a GUI toolkit for Python that is a wrapper around the
wxWindows C++ GUI library.  wxPython provides a large variety of
window types and controls, all implemented with a native look and feel
(and native runtime speed) on the platforms it is supported on.

This package contains the wxversion python module needed if several versions of
wxPython are installed.

%package        tools
Summary:        Example applications from %{name}
Group:          Development/Python
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    tools
wxPython is a GUI toolkit for Python that is a wrapper around the
wxWindows C++ GUI library.  wxPython provides a large variety of
window types and controls, all implemented with a native look and feel
(and native runtime speed) on the platforms it is supported on.

This contains the example applications that come with wxPython like
PyShell and XRCed.

%package -n     %libname-devel
Summary:        Development files of %{name}
Group:          Development/Python
Provides:       libwxPython-devel = %{epoch}:%{version}-%{release}
Provides:       libwxPythonGTK-devel = %{epoch}:%{version}-%{release}
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       wxgtk-devel >= %{wxgtku_ver}

%description -n %libname-devel
This packages contains the headers and etc. for building apps or
Python extension modules that use the same wx%{port} shared libraries
that wxPython uses.

%package        docs
Group:          Documentation
Summary:        Documentation and samples for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch

%description    docs
Documentation, samples and demo application for wxPython.

%prep
%setup -q -n %{tarname}-%{version}/wxPython
%autopatch -p1

# fix libdir otherwise additional wx libs cannot be found
sed -i -e 's|/usr/lib|%{_libdir}|' -e 's|-O3|-O2|' config.py

%build
# (Fedora) included distutils is not multilib aware; use normal
rm -rf distutils
%py2_build

%install
%py2_install

# install Mageia menu items
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-pyshell.desktop << EOF
[Desktop Entry]
Name=PyShell
Comment=GUI Python Shell
Exec=%{_bindir}/pyshell %U
Icon=PyCrust
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-pycrust.desktop << EOF
[Desktop Entry]
Name=PyCrust
Comment=GUI Python Shell with Filling
Exec=%{_bindir}/pycrust %U
Icon=PyCrust
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-pyalamode.desktop << EOF
[Desktop Entry]
Name=PyAlaMode
Comment=GUI Python Shell with Filling and Editor Windows
Exec=%{_bindir}/pyalamode %U
Icon=PyCrust
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-xrced.desktop << EOF
[Desktop Entry]
Name=XRCed
Comment=XRC resource editor for wxPython
Exec=%{_bindir}/xrced %U
Icon=XRCed
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-editra.desktop << EOF
[Desktop Entry]
Name=Editra
Comment="Programmer's Text Editor"
Exec=/usr/bin/editra
Icon=editra
Terminal=false
Type=Application
Categories=GNOME;GTK;Development;
StartupNotify=true
EOF

#icons
#cd wxPython
mkdir -p %{buildroot}%{_miconsdir}
install -m 644 wx/py/PyCrust_16.png %{buildroot}%{_miconsdir}/PyCrust.png
install -m 644 wx/py/PyCrust_32.png %{buildroot}%{_iconsdir}/PyCrust.png
install -m 644 wx/tools/XRCed/XRCed_16.png %{buildroot}%{_miconsdir}/XRCed.png
install -m 644 wx/tools/XRCed/XRCed_32.png %{buildroot}%{_iconsdir}/XRCed.png

mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,64x64,128x128}/apps
convert -scale 16x16 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/editra.png
convert -scale 32x32 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/editra.png
convert -scale 64x64 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/editra.png
install -m 644 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/editra.png

#gw fix paths
%if "%{python2_sitelib}" != "%{python2_sitearch}"
mv %{buildroot}%{python2_sitelib}/* %{buildroot}%{python2_sitearch}
%endif

# don't ship these ones, firstly we have python >= 2.7, and secondly they mess
# with the pythoneggs.py auto-requires generation
%if "%{python2_version}" >= "2.7"
rm -fr %{buildroot}%{python2_sitearch}/wx-%{api}-gtk%{gtkver}/wx/tools/Editra/plugins/{*py2.5.egg,*py2.6.egg}
%endif

%files
%license licence/*
%{python2_sitearch}/wx.pth
%{python2_sitearch}/*.egg-info
%dir %{python2_sitearch}/wx-%{api}-gtk%{gtkver}
%{python2_sitearch}/wx-%{api}-gtk%{gtkver}/wx
%{python2_sitearch}/wx-%{api}-gtk%{gtkver}/*.egg-info

%files tools
%{_bindir}/*
%{_datadir}/applications/%{_real_vendor}-*
%{_iconsdir}/*.png
%{_miconsdir}/*.png
%{_iconsdir}/hicolor/*/*/*.png

%files wxversion
%{python2_sitearch}/wxversion*

%files -n %libname-devel
%{_includedir}/wx-%{api}/wx/wxPython

%files docs
%doc docs/*.*
%doc docs/screenshots


%changelog
* Sat Jun 03 2017 akien <akien> 1:3.0.2.0-8.mga6
+ Revision: 1106133
- Rebuild for wxgtk 3.0.3.1

* Thu Jun 02 2016 daviddavid <daviddavid> 1:3.0.2.0-7.mga6
+ Revision: 1019796
- rebuild for wxgtk3.0 built with GTK2
- use new python macros

* Wed Feb 17 2016 umeabot <umeabot> 1:3.0.2.0-6.mga6
+ Revision: 963301
- Mageia 6 Mass Rebuild

  + wally <wally>
    - drop old Mdv era obsoletes

* Wed Aug 26 2015 ns80 <ns80> 1:3.0.2.0-5.mga6
+ Revision: 869697
- rebuild for new wxgtk built with gcc5

* Fri Aug 14 2015 ycantin <ycantin> 1:3.0.2.0-4.mga6
+ Revision: 864759
- rebuild for new wxgtk built with wxRE_ADVANCED

* Wed Jul 22 2015 philippem <philippem> 1:3.0.2.0-3.mga6
+ Revision: 856162
- remove wrong dependencies

* Wed Jul 22 2015 philippem <philippem> 1:3.0.2.0-2.mga6
+ Revision: 856152
- build with gtk3

* Sun Jun 28 2015 akien <akien> 1:3.0.2.0-1.mga6
+ Revision: 847197
- Version 3.0.2.0

* Thu Nov 20 2014 wally <wally> 1:3.0.1.1-1.mga5
+ Revision: 797954
- new version 3.0.1.1

* Wed Oct 15 2014 umeabot <umeabot> 1:3.0.0.0-5.mga5
+ Revision: 742753
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:3.0.0.0-4.mga5
+ Revision: 730731
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:3.0.0.0-3.mga5
+ Revision: 690380
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Mon Feb 17 2014 fwang <fwang> 1:3.0.0.0-1.mga5
+ Revision: 593400
- update file list
- update file list
- more str fmt patch
- fix str fmt
- update build requires
- 3.0.0.0

* Tue Oct 22 2013 umeabot <umeabot> 1:2.8.12.1-5.mga4
+ Revision: 544711
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1:2.8.12.1-4.mga4
+ Revision: 499998
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Feb 11 2013 fwang <fwang> 1:2.8.12.1-3.mga3
+ Revision: 397813
- update doc list
- add versioned obsoletes
- add patch to work with latest pycairo

* Mon Jan 14 2013 umeabot <umeabot> 1:2.8.12.1-2.mga3
+ Revision: 385893
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 20 2012 fwang <fwang> 1:2.8.12.1-1.mga2
+ Revision: 198663
- new version 2.8.12.1

  + ahmad <ahmad>
    - Rebuild against wxgtk2.8 with enabled catch_segvs

* Tue Jun 21 2011 ahmad <ahmad> 1:2.8.12.0-1.mga2
+ Revision: 111200
- Update to 2.8.12.0
- Don't disable build the debug package (a wrong commit a couple of months ago)

* Fri Feb 25 2011 ahmad <ahmad> 1:2.8.11.0-5.mga1
+ Revision: 59947
- rebuild against wxgtk2.8 after adding more BR (to wxgtk2.8)
- obsolete old libwxPythonGTK2.8 instead of conflicting

* Mon Feb 21 2011 ahmad <ahmad> 1:2.8.11.0-4.mga1
+ Revision: 55075
- add BR imagemagick
- we don't need all those BR (Fedora)
- install editro.desktop and editra.png icons
- don't disable installing scripts (let them be copied automatically)
- don't ship 2.5 and 2.6 python eggs, we don't have python 2.5 or 2.6; and these
  eggs mess the python auto-requires
- only build wxPython, we already have wxWidgets from the wxgtku2.8 package
- make the first step of renaming the package to wxPython
- drop the lib package, now the libs come from wxgtku2.8
- add/modify the necessary obsoletes/conflicts/requires tags
- add patch to fix linking

  + dmorgan <dmorgan>
    - Rename desktop files

  + ennael <ennael>
    - remove mdkversion

  + misc <misc>
    - imported package wxPythonGTK

